pub struct DeviceProxy { /* private fields */ }Implementations
Sourceimpl DeviceProxy
impl DeviceProxy
Sourcepub fn take_event_stream(&self) -> DeviceEventStream
pub fn take_event_stream(&self) -> DeviceEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_info(&self) -> QueryResponseFut<DeviceInfo, FDomainResourceDialect>
pub fn get_info(&self) -> QueryResponseFut<DeviceInfo, FDomainResourceDialect>
Obtain information about device
- response
infodevice information.
Sourcepub fn open_session(
&self,
session_name: &str,
session_info: SessionInfo,
) -> QueryResponseFut<DeviceOpenSessionResult, FDomainResourceDialect>
pub fn open_session( &self, session_name: &str, session_info: SessionInfo, ) -> QueryResponseFut<DeviceOpenSessionResult, FDomainResourceDialect>
Opens a new session with the network device.
- request
session_nameis used as a debugging label attached to this session. - request
session_infocontains the necessary information to setup the session’s data exchange.
- response
sessiona handle to control the session. - response
fifosdata-plane FIFOs attached to the session.
- error
ZX_ERR_NOT_SUPPORTEDifsession_infocontains not supported frame types or descriptors set up. - error
ZX_ERR_INVALID_ARGSifsession_infois missing fields or contains invalid information. - error
ZX_ERR_INTERNALif the data VMO is rejected by the underlying device.
Sourcepub fn get_port(
&self,
id: &PortId,
port: ServerEnd<PortMarker>,
) -> Result<(), Error>
pub fn get_port( &self, id: &PortId, port: ServerEnd<PortMarker>, ) -> Result<(), Error>
Connects to a port the given id.
- request
idport to connect to. - request
portserver end of port channel.
port is closed with a ZX_ERR_NOT_FOUND epitaph if no port with id
exists.
Sourcepub fn get_port_watcher(
&self,
watcher: ServerEnd<PortWatcherMarker>,
) -> Result<(), Error>
pub fn get_port_watcher( &self, watcher: ServerEnd<PortWatcherMarker>, ) -> Result<(), Error>
Connects a [PortWatcher] to this device.
- request
watcherserver end of watcher channel.