pub struct EthernetFeatures(/* private fields */);Expand description
Ethernet frame sub-types and features.
Implementations
Sourceimpl EthernetFeatures
impl EthernetFeatures
Sourcepub const RAW: EthernetFeatures
pub const RAW: EthernetFeatures
Device supports any type of ethernet frame.
Same as specifying all other flags. Used by devices that do not inspect or parse outbound traffic.
Sourcepub const ETHERNET_II: EthernetFeatures
pub const ETHERNET_II: EthernetFeatures
Device supports EthernetII frames.
Sourcepub const E_802_1_Q: EthernetFeatures
pub const E_802_1_Q: EthernetFeatures
Device supports 802.1q VLAN additions.
Sourcepub const E_802_1_Q_IN_Q: EthernetFeatures
pub const E_802_1_Q_IN_Q: EthernetFeatures
Device supports 802.1 q-in-q Multiple VLAN tagging additions.
Only meaningful if E_802_1_Q is also present.
Sourcepub const E_802_3_LLC_SNAP: EthernetFeatures
pub const E_802_3_LLC_SNAP: EthernetFeatures
Device supports 802.3 LLC + SNAP Ethernet frame format.
Sourceimpl EthernetFeatures
impl EthernetFeatures
Sourcepub const fn empty() -> EthernetFeatures
pub const fn empty() -> EthernetFeatures
Get a flags value with all bits unset.
Sourcepub const fn all() -> EthernetFeatures
pub const fn all() -> EthernetFeatures
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<EthernetFeatures>
pub const fn from_bits(bits: u32) -> Option<EthernetFeatures>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> EthernetFeatures
pub const fn from_bits_truncate(bits: u32) -> EthernetFeatures
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> EthernetFeatures
pub const fn from_bits_retain(bits: u32) -> EthernetFeatures
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<EthernetFeatures>
pub fn from_name(name: &str) -> Option<EthernetFeatures>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: EthernetFeatures) -> bool
pub const fn intersects(&self, other: EthernetFeatures) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: EthernetFeatures) -> bool
pub const fn contains(&self, other: EthernetFeatures) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: EthernetFeatures)
pub fn insert(&mut self, other: EthernetFeatures)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: EthernetFeatures)
pub fn remove(&mut self, other: EthernetFeatures)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: EthernetFeatures)
pub fn toggle(&mut self, other: EthernetFeatures)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: EthernetFeatures, value: bool)
pub fn set(&mut self, other: EthernetFeatures, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: EthernetFeatures) -> EthernetFeatures
pub const fn intersection(self, other: EthernetFeatures) -> EthernetFeatures
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: EthernetFeatures) -> EthernetFeatures
pub const fn union(self, other: EthernetFeatures) -> EthernetFeatures
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: EthernetFeatures) -> EthernetFeatures
pub const fn difference(self, other: EthernetFeatures) -> EthernetFeatures
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: EthernetFeatures,
) -> EthernetFeatures
pub const fn symmetric_difference( self, other: EthernetFeatures, ) -> EthernetFeatures
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> EthernetFeatures
pub const fn complement(self) -> EthernetFeatures
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl EthernetFeatures
impl EthernetFeatures
Sourcepub const fn iter(&self) -> Iter<EthernetFeatures>
pub const fn iter(&self) -> Iter<EthernetFeatures>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EthernetFeatures>
pub const fn iter_names(&self) -> IterNames<EthernetFeatures>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.