pub struct MacAddressingControlHandle { /* private fields */ }Trait Implementations
Sourceimpl Clone for MacAddressingControlHandle
impl Clone for MacAddressingControlHandle
Sourcefn clone(&self) -> MacAddressingControlHandle
fn clone(&self) -> MacAddressingControlHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ControlHandle for MacAddressingControlHandle
impl ControlHandle for MacAddressingControlHandle
Sourcefn shutdown(&self)
fn shutdown(&self)
Set the server to shutdown. The underlying channel is only closed the
next time the stream is polled.
Sourcefn shutdown_with_epitaph(&self, status: Status)
fn shutdown_with_epitaph(&self, status: Status)
Sets the server to shutdown with an epitaph. The underlying channel is
only closed the next time the stream is polled.
Sourcefn on_closed(&self) -> OnFDomainSignals
fn on_closed(&self) -> OnFDomainSignals
Returns a future that completes when the server receives the
PEER_CLOSED signal.Auto Trait Implementations
impl Freeze for MacAddressingControlHandle
impl !RefUnwindSafe for MacAddressingControlHandle
impl Send for MacAddressingControlHandle
impl Sync for MacAddressingControlHandle
impl Unpin for MacAddressingControlHandle
impl UnsafeUnpin for MacAddressingControlHandle
impl !UnwindSafe for MacAddressingControlHandle