pub struct PortControlHandle { /* private fields */ }Trait Implementations
Sourceimpl Clone for PortControlHandle
impl Clone for PortControlHandle
Sourcefn clone(&self) -> PortControlHandle
fn clone(&self) -> PortControlHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ControlHandle for PortControlHandle
impl ControlHandle for PortControlHandle
Sourcefn shutdown(&self)
fn shutdown(&self)
Set the server to shutdown. The underlying channel is only closed the
next time the stream is polled.
Sourcefn shutdown_with_epitaph(&self, status: Status)
fn shutdown_with_epitaph(&self, status: Status)
Sets the server to shutdown with an epitaph. The underlying channel is
only closed the next time the stream is polled.
Sourcefn on_closed(&self) -> OnFDomainSignals
fn on_closed(&self) -> OnFDomainSignals
Returns a future that completes when the server receives the
PEER_CLOSED signal.Auto Trait Implementations
impl Freeze for PortControlHandle
impl !RefUnwindSafe for PortControlHandle
impl Send for PortControlHandle
impl Sync for PortControlHandle
impl Unpin for PortControlHandle
impl UnsafeUnpin for PortControlHandle
impl !UnwindSafe for PortControlHandle