pub struct PortWatcherProxy { /* private fields */ }Implementations
Sourceimpl PortWatcherProxy
impl PortWatcherProxy
Sourcepub fn new(channel: Channel) -> Self
pub fn new(channel: Channel) -> Self
Create a new Proxy for fuchsia.hardware.network/PortWatcher.
Sourcepub fn take_event_stream(&self) -> PortWatcherEventStream
pub fn take_event_stream(&self) -> PortWatcherEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch(&self) -> QueryResponseFut<DevicePortEvent, FDomainResourceDialect>
pub fn watch(&self) -> QueryResponseFut<DevicePortEvent, FDomainResourceDialect>
Get the next port event.
The first N calls return [DevicePortEvent.existing] where N is the
number of ports present on the device at the time of the watcher’s
creation. The next call returns [DevicePortEvent.idle] to indicate the
end of existing ports. Subsequent calls block until a port is added
([DevicePortEvent.added]) or removed ([DevicePortEvent.removed]).
The server closes the PortWatcher channel with ZX_ERR_CANCELED if
the number of unread events reaches a server-selected limit that is at
least two times MAX_PORTS. Clients are encouraged to maintain a
hanging call to Watch at all times to avoid triggering this condition.
- response
eventnext port event.