pub struct SessionInfo {
pub descriptors: Option<Vmo>,
pub data: Option<Vec<DataVmo>>,
pub descriptor_version: Option<u8>,
pub descriptor_length: Option<u8>,
pub descriptor_count: Option<u16>,
pub options: Option<SessionFlags>,
/* private fields */
}Expand description
Session configuration.
Fields
descriptors: Option<Vmo>VMO containing the descriptors. Required.
16-bit indices transmitted over the FIFOs index a descriptor in this VMO (byte offset = descriptor_length * 8 * index).
data: Option<Vec<DataVmo>>VMOs containing frame data. Required
Descriptors contain byte-offsets and vmo ids that are used to index regions in data VMOs.
descriptor_version: Option<u8>Requested descriptor version. Required.
If the network device does not support the requested descriptor version,
[Device.OpenSession] fails with ZX_ERR_NOT_SUPPORTED.
descriptor_length: Option<u8>Descriptor length, in 64-bit words. Required.
The length of each descriptor in the descriptors VMO. This is used as
a multiplier to find byte offsets in descriptors given a descriptor
index passed through the rx or tx FIFOs.
descriptor_count: Option<u16>Total number of descriptors that can be used by this session. Required.
Descriptor indices transferred through either the rx or tx FIFO must be
in the range [0, descriptor_count).
options: Option<SessionFlags>Extra options. Interpreted as empty bitmask if absent.