pub struct StatusFlags(/* private fields */);Expand description
Port status bits, reported in [PortStatus.flags].
Implementations
Sourceimpl StatusFlags
impl StatusFlags
Sourcepub const ONLINE: StatusFlags
pub const ONLINE: StatusFlags
Port is online, i.e., data path is open and any ongoing sessions may send and receive frames.
Sourceimpl StatusFlags
impl StatusFlags
Sourcepub const fn empty() -> StatusFlags
pub const fn empty() -> StatusFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> StatusFlags
pub const fn all() -> StatusFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<StatusFlags>
pub const fn from_bits(bits: u32) -> Option<StatusFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> StatusFlags
pub const fn from_bits_truncate(bits: u32) -> StatusFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> StatusFlags
pub const fn from_bits_retain(bits: u32) -> StatusFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<StatusFlags>
pub fn from_name(name: &str) -> Option<StatusFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: StatusFlags) -> bool
pub const fn intersects(&self, other: StatusFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: StatusFlags) -> bool
pub const fn contains(&self, other: StatusFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: StatusFlags)
pub fn insert(&mut self, other: StatusFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: StatusFlags)
pub fn remove(&mut self, other: StatusFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: StatusFlags)
pub fn toggle(&mut self, other: StatusFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: StatusFlags, value: bool)
pub fn set(&mut self, other: StatusFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: StatusFlags) -> StatusFlags
pub const fn intersection(self, other: StatusFlags) -> StatusFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: StatusFlags) -> StatusFlags
pub const fn union(self, other: StatusFlags) -> StatusFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: StatusFlags) -> StatusFlags
pub const fn difference(self, other: StatusFlags) -> StatusFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: StatusFlags) -> StatusFlags
pub const fn symmetric_difference(self, other: StatusFlags) -> StatusFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> StatusFlags
pub const fn complement(self) -> StatusFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl StatusFlags
impl StatusFlags
Sourcepub const fn iter(&self) -> Iter<StatusFlags>
pub const fn iter(&self) -> Iter<StatusFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<StatusFlags>
pub const fn iter_names(&self) -> IterNames<StatusFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.