pub struct TxReturnFlags(/* private fields */);Expand description
Flags set by a Device when returning a tx buffer back to a client.
Set by Devices on the return_flags field of a tx descriptor.
Implementations
Sourceimpl TxReturnFlags
impl TxReturnFlags
Sourcepub const TX_RET_NOT_SUPPORTED: TxReturnFlags
pub const TX_RET_NOT_SUPPORTED: TxReturnFlags
Requested operation in inbound_flags is not supported; the frame was
not sent.
Always set in conjunction with TX_RET_ERROR.
Sourcepub const TX_RET_OUT_OF_RESOURCES: TxReturnFlags
pub const TX_RET_OUT_OF_RESOURCES: TxReturnFlags
Could not allocate resources to send frame.
Always set in conjunction with TX_RET_ERROR.
Sourcepub const TX_RET_NOT_AVAILABLE: TxReturnFlags
pub const TX_RET_NOT_AVAILABLE: TxReturnFlags
Device is not available (offline or disconnected); the frame was not sent.
Always set in conjunction with TX_RET_ERROR.
pub const TX_RET_ERROR: TxReturnFlags
Sourceimpl TxReturnFlags
impl TxReturnFlags
Sourcepub const fn empty() -> TxReturnFlags
pub const fn empty() -> TxReturnFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> TxReturnFlags
pub const fn all() -> TxReturnFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<TxReturnFlags>
pub const fn from_bits(bits: u32) -> Option<TxReturnFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> TxReturnFlags
pub const fn from_bits_truncate(bits: u32) -> TxReturnFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> TxReturnFlags
pub const fn from_bits_retain(bits: u32) -> TxReturnFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<TxReturnFlags>
pub fn from_name(name: &str) -> Option<TxReturnFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: TxReturnFlags) -> bool
pub const fn intersects(&self, other: TxReturnFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: TxReturnFlags) -> bool
pub const fn contains(&self, other: TxReturnFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: TxReturnFlags)
pub fn insert(&mut self, other: TxReturnFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: TxReturnFlags)
pub fn remove(&mut self, other: TxReturnFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: TxReturnFlags)
pub fn toggle(&mut self, other: TxReturnFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: TxReturnFlags, value: bool)
pub fn set(&mut self, other: TxReturnFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: TxReturnFlags) -> TxReturnFlags
pub const fn intersection(self, other: TxReturnFlags) -> TxReturnFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: TxReturnFlags) -> TxReturnFlags
pub const fn union(self, other: TxReturnFlags) -> TxReturnFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: TxReturnFlags) -> TxReturnFlags
pub const fn difference(self, other: TxReturnFlags) -> TxReturnFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: TxReturnFlags) -> TxReturnFlags
pub const fn symmetric_difference(self, other: TxReturnFlags) -> TxReturnFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> TxReturnFlags
pub const fn complement(self) -> TxReturnFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl TxReturnFlags
impl TxReturnFlags
Sourcepub const fn iter(&self) -> Iter<TxReturnFlags>
pub const fn iter(&self) -> Iter<TxReturnFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TxReturnFlags>
pub const fn iter_names(&self) -> IterNames<TxReturnFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl TxReturnFlags
impl TxReturnFlags
pub fn from_bits_allow_unknown(bits: u32) -> TxReturnFlags
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32